@@ -6,22 +6,20 @@
 # This software may be used and distributed according to the terms
 # of the GNU General Public License, incorporated herein by reference.
 
-from __future__ import generator_stop
-
 # global modules
 import os
 
-# local modules
-from . import compat
-from . import gitrepo
-from . import util
-
 from mercurial import (
     bookmarks,
     exthelper,
     hg,
     localrepo,
 )
+from mercurial.utils import urlutil
+
+# local modules
+from . import gitrepo
+from . import util
 
 eh = exthelper.exthelper()
 
@@ -72,7 +70,7 @@ class RepoFactory:
 
     def instance(self, ui, path, *args, **kwargs):
         if isinstance(path, bytes):
-            url = compat.url(path)
+            url = urlutil.url(path)
         else:
             url = path.url
 
@@ -80,11 +78,8 @@ class RepoFactory:
         # detect git ssh urls (which mercurial thinks is a file-like path)
         if isgitdir(p) or util.isgitsshuri(p) or p.endswith(b'.git'):
             fn = gitrepo.instance
-        elif hasattr(self.__orig, 'instance'):
-            fn = self.__orig.instance
         else:
-            # prior to Mercurial 6.4
-            fn = self.__orig
+            fn = self.__orig.instance
 
         return fn(ui, path, *args, **kwargs)
 
@@ -99,7 +94,7 @@ class RepoFactory:
         return fn(ui, path, *args, **kwargs)
 
 
-@eh.wrapfunction(hg, b'defaultdest')
+@eh.wrapfunction(hg, 'defaultdest')
 def defaultdest(orig, source):
     if source.endswith(b'.git'):
         return orig(source[:-4])
@@ -107,7 +102,7 @@ def defaultdest(orig, source):
     return orig(source)
 
 
-@eh.wrapfunction(hg, b'peer')
+@eh.wrapfunction(hg, 'peer')
 def peer(orig, uiorrepo, *args, **opts):
     newpeer = orig(uiorrepo, *args, **opts)
     if isinstance(newpeer, gitrepo.gitrepo):
@@ -116,7 +111,7 @@ def peer(orig, uiorrepo, *args, **opts):
     return newpeer
 
 
-@eh.wrapfunction(hg, b'clone')
+@eh.wrapfunction(hg, 'clone')
 def clone(orig, *args, **opts):
     srcpeer, destpeer = orig(*args, **opts)
 
@@ -127,24 +122,24 @@ def clone(orig, *args, **opts):
     return srcpeer, destpeer
 
 
-@eh.wrapfunction(compat.path, b'_isvalidlocalpath')
+@eh.wrapfunction(urlutil.path, '_isvalidlocalpath')
 def isvalidlocalpath(orig, self, path):
     return orig(self, path) or isgitdir(path)
 
 
-@eh.wrapfunction(compat.url, b'islocal')
+@eh.wrapfunction(urlutil.url, 'islocal')
 def isurllocal(orig, path):
     # recognise git scp-style paths when cloning
     return orig(path) and not util.isgitsshuri(path._origpath)
 
 
-@eh.wrapfunction(hg, b'islocal')
+@eh.wrapfunction(hg, 'islocal')
 def islocal(orig, path):
     # recognise git scp-style paths when cloning
     return orig(path) and not util.isgitsshuri(path)
 
 
-@eh.wrapfunction(compat.urlutil, b'hasscheme')
+@eh.wrapfunction(urlutil, 'hasscheme')
 def hasscheme(orig, path):
     # recognise git scp-style paths
     return orig(path) or util.isgitsshuri(path)
@@ -152,45 +147,11 @@ def hasscheme(orig, path):
 
 @eh.extsetup
 def extsetup(ui):
-    # added in Mercurial 6.4
-    if hasattr(hg, 'repo_schemes') and hasattr(hg, 'peer_schemes'):
-        peer_schemes = hg.peer_schemes
-
-        hg.peer_schemes[b'https'] = RepoFactory(hg.peer_schemes[b'https'])
-        hg.peer_schemes[b'http'] = RepoFactory(hg.peer_schemes[b'http'])
-        hg.repo_schemes[b'file'] = RepoFactory(hg.repo_schemes[b'file'])
-
-    else:
-        peer_schemes = hg.schemes
-
-        _oldlocal = hg.schemes[b'file']
-
-        def _local(path):
-            p = compat.url(path).localpath()
-            if isgitdir(p):
-                return gitrepo
-            # detect git ssh urls (which mercurial thinks is a file-like path)
-            if util.isgitsshuri(p):
-                return gitrepo
-            return _oldlocal(path)
-
-        def _httpgitwrapper(orig):
-            # we should probably test the connection but for now, we just keep it
-            # simple and check for a url ending in '.git'
-            def httpgitscheme(uri):
-                if uri.endswith(b'.git'):
-                    return gitrepo
-
-                # the http(s) scheme just returns the _peerlookup
-                return orig
-
-            return httpgitscheme
-
-        hg.schemes[b'https'] = _httpgitwrapper(hg.schemes[b'https'])
-        hg.schemes[b'http'] = _httpgitwrapper(hg.schemes[b'http'])
-        hg.schemes[b'file'] = _local
+    hg.peer_schemes[b'https'] = RepoFactory(hg.peer_schemes[b'https'])
+    hg.peer_schemes[b'http'] = RepoFactory(hg.peer_schemes[b'http'])
+    hg.repo_schemes[b'file'] = RepoFactory(hg.repo_schemes[b'file'])
 
     # support for `hg clone git://github.com/defunkt/facebox.git`
     # also hg clone git+ssh://git@github.com/schacon/simplegit.git
     for _scheme in util.gitschemes:
-        peer_schemes[_scheme] = gitrepo
+        hg.peer_schemes[_scheme] = gitrepo
